@@ -9,15 +9,15 @@
 #' @param r2_thres Threshold for calibration regression to be used to
 #'          calibrate standards data. Default is 0.95. Calibrated reference
 #'          gas measurements occurring during calibration periods
-#'          with r2 values less than \code{r2_thres} will be marked NA.
+#'          with r2 values less than `r2_thres` will be marked NA.
 #' @param correct_bad_refvals Should we correct known/suspected incorrect
-#'          reference values in the NEON HDF5 files? (Default = \code{FALSE}).
+#'          reference values in the NEON HDF5 files? (Default = `FALSE`).
 #' @param site Four letter NEON site code.
-#'             Only used if \code{correct_bad_refvals = TRUE}.
+#'             Only used if `correct_bad_refvals = TRUE`.
 #' @param refGas One of "low", "med", or "high."
-#'             Only used if \code{correct_bad_refvals = TRUE}.
+#'             Only used if `correct_bad_refvals = TRUE`.
 #'             
-#' @return A data.frame having the same number of rows of \code{cal_df}, with
+#' @return A data.frame having the same number of rows of `cal_df`, with
 #'        additional columns added for calibrated CO2 mole fractions
 #'        and d13C values.
 calibrate_standards_carbon <- function(cal_df,
@@ -232,145 +232,145 @@ calibrate_standards_carbon <- function(cal_df,
     }
   }
   
-  # check to see how many rows cal_df has
-  if ("gain12C" %in% names(cal_df)) {
-    
-    # check to ensure there are actual standard measurements for this month!
-    if (nrow(ref_df$dlta13CCo2) > 1) {
-
-      for (i in 2:nrow(ref_df$dlta13CCo2)) {
-        # note: starts at 2 because periods are defined as
-        # extending to the end time of standard measurement i
-        # to the endtime of stanard measurement i + 1.
-
-        # determine which row calibration point is in.
-        int <- lubridate::interval(cal_df$start, cal_df$end)
-
-        cal_id <- which(ref_df$dlta13CCo2$timeBgn[i] %within% int)
-
-        # now, calculate calibrated value ONLY IF CERTAIN CONDITIONS ARE MET:
-        # 1a-d. variables needed are not missing.
-        # 2. at least 200 ~1Hz measurements available (e.g., valve issues)
-        # 3. meets tolerance between ref and measured d13C
-        # 4. meets tolerance between ref and measured CO2
-        # 5. meets tolerance of d13C variance
-        # these conditions are listed in this order in the logical below.
-        if (!is.na(ref_df$dlta13CCo2$mean[i]) &
-            !is.na(ref_df$dlta13CCo2Refe$mean[i]) &
-            !is.na(ref_df$rtioMoleDryCo2$mean[i]) &
-            !is.na(ref_df$rtioMoleDryCo2Refe$mean[i]) &
-            ref_df$dlta13CCo2$numSamp[i] >= 200 &
-            abs(ref_df$dlta13CCo2$mean[i] -
-                ref_df$dlta13CCo2Refe$mean[i]) < 5 &
-            abs(ref_df$rtioMoleDryCo2$mean[i] -
-                ref_df$rtioMoleDryCo2Refe$mean[i]) < 10 &
-            ref_df$dlta13CCo2$vari[i] < 5) {
-
-          if (!(length(cal_id) == 0)) {
-            # calibrate isotopologues using appropriate cal_id
-            uncal_12C <- ref_df$rtioMoleDryCo2$mean[i] * (1 - f) /
-              (1 + R_vpdb * (1 + ref_df$dlta13CCo2$mean[i] / 1000))
-
-            uncal_13C <- ref_df$rtioMoleDryCo2$mean[i] * (1 - f) - uncal_12C
-
-            cal_12C <- cal_df$gain12C[cal_id] * uncal_12C +
-              cal_df$offset12C[cal_id]
-            cal_13C <- cal_df$gain13C[cal_id] * uncal_13C +
-              cal_df$offset13C[cal_id]
-
-            if (!is.na(cal_df$r2_12C[cal_id]) &
-                !is.na(cal_df$r2_13C[cal_id]) &
-                cal_df$r2_12C[cal_id] > r2_thres &
-                cal_df$r2_13C[cal_id] > r2_thres) {
-              ref_df$dlta13CCo2$mean_cal[i] <- round(1000 * (cal_13C /
-                                                     cal_12C / R_vpdb - 1), 3)
-              ref_df$rtioMoleDryCo2$mean_cal[i] <- (cal_13C + cal_12C) /
-                                                      (1 - f)
-
-            } else {
-
-              ref_df$dlta13CCo2$mean_cal[i] <- NA
-              ref_df$rtioMoleDryCo2$mean_cal[i] <- NA
-
-            }
-
-          } else {
-
-            ref_df$dlta13CCo2$mean_cal[i] <- NA
-            ref_df$rtioMoleDryCo2$mean_cal[i] <- NA
-
-          }
-
-        } else {
-
-          ref_df$dlta13CCo2$mean_cal[i] <- NA
-          ref_df$rtioMoleDryCo2$mean_cal[i] <- NA
-        }
-      }
-    }
-
-  } else {
-
-    if (nrow(ref_df$dlta13CCo2) > 1) {
-      for (i in 2:nrow(ref_df$dlta13CCo2)) { # use n-1 because of bracketing
-
-        # determine which row calibration point is in.
-        int <- lubridate::interval(cal_df$start, cal_df$end)
-        cal_id <- which(ref_df$dlta13CCo2$timeBgn[i] %within% int)
-
-        # now, calculate calibrated value ONLY IF CERTAIN CONDITIONS ARE MET:
-        # 1a-d. variables needed are not missing.
-        # 2. at least 200 ~1Hz measmnts available (filters out valve issues)
-        # 3. meets tolerance between ref and measured d13C
-        # 4. meets tolerance between ref and measured CO2
-        # 5. meets tolerance of d13C variance
-        # these conditions are listed in this order in the logical below.
-        if (!is.na(ref_df$dlta13CCo2$mean[i]) &
-            !is.na(ref_df$dlta13CCo2Refe$mean[i]) &
-            !is.na(ref_df$rtioMoleDryCo2$mean[i]) &
-            !is.na(ref_df$rtioMoleDryCo2Refe$mean[i]) &
-            ref_df$dlta13CCo2$numSamp[i] >= 200 &
-            abs(ref_df$dlta13CCo2$mean[i] -
-                ref_df$dlta13CCo2Refe$mean[i]) < 5 &
-            abs(ref_df$rtioMoleDryCo2$mean[i] -
-                ref_df$rtioMoleDryCo2Refe$mean[i]) < 10 &
-            ref_df$dlta13CCo2$vari[i] < 5) {
-
-          if (!length(cal_id) == 0) {
-
-            if (!is.na(cal_df$d13C_r2[cal_id]) &
-                !is.na(cal_df$co2_r2[cal_id]) &
-                cal_df$d13C_r2[cal_id] > r2_thres &
-                cal_df$co2_r2[cal_id] > r2_thres) {
-
-              ref_df$dlta13CCo2$mean_cal[i] <- cal_df$d13C_intercept[cal_id] +
-                cal_df$d13C_slope[cal_id] * ref_df$dlta13CCo2$mean[i]
-
-              ref_df$rtioMoleDryCo2$mean_cal[i] <- cal_df$co2_intercept[cal_id] +
-                cal_df$co2_slope[cal_id] * ref_df$rtioMoleDryCo2$mean[i]
-
-            } else {
-
-              ref_df$dlta13CCo2$mean_cal[i] <- NA
-              ref_df$rtioMoleDryCo2$mean_cal[i] <- NA
-            }
-
-          } else {
-
-            ref_df$dlta13CCo2$mean_cal[i] <- NA
-            ref_df$rtioMoleDryCo2$mean_cal[i] <- NA
-
-          }
-
-        } else {
-
-          ref_df$dlta13CCo2$mean_cal[i] <- NA
-          ref_df$rtioMoleDryCo2$mean_cal[i] <- NA
-
-        }
-      }
-    }
-  }
+  # # check to see how many rows cal_df has
+  # if ("gain12C" %in% names(cal_df)) {
+  #   
+  #   # check to ensure there are actual standard measurements for this month!
+  #   if (nrow(ref_df$dlta13CCo2) > 1) {
+  # 
+  #     for (i in 2:nrow(ref_df$dlta13CCo2)) {
+  #       # note: starts at 2 because periods are defined as
+  #       # extending to the end time of standard measurement i
+  #       # to the endtime of stanard measurement i + 1.
+  # 
+  #       # determine which row calibration point is in.
+  #       int <- lubridate::interval(cal_df$start, cal_df$end)
+  # 
+  #       cal_id <- which(ref_df$dlta13CCo2$timeBgn[i] %within% int)
+  # 
+  #       # now, calculate calibrated value ONLY IF CERTAIN CONDITIONS ARE MET:
+  #       # 1a-d. variables needed are not missing.
+  #       # 2. at least 200 ~1Hz measurements available (e.g., valve issues)
+  #       # 3. meets tolerance between ref and measured d13C
+  #       # 4. meets tolerance between ref and measured CO2
+  #       # 5. meets tolerance of d13C variance
+  #       # these conditions are listed in this order in the logical below.
+  #       if (!is.na(ref_df$dlta13CCo2$mean[i]) &
+  #           !is.na(ref_df$dlta13CCo2Refe$mean[i]) &
+  #           !is.na(ref_df$rtioMoleDryCo2$mean[i]) &
+  #           !is.na(ref_df$rtioMoleDryCo2Refe$mean[i]) &
+  #           ref_df$dlta13CCo2$numSamp[i] >= 200 &
+  #           abs(ref_df$dlta13CCo2$mean[i] -
+  #               ref_df$dlta13CCo2Refe$mean[i]) < 5 &
+  #           abs(ref_df$rtioMoleDryCo2$mean[i] -
+  #               ref_df$rtioMoleDryCo2Refe$mean[i]) < 10 &
+  #           ref_df$dlta13CCo2$vari[i] < 5) {
+  # 
+  #         if (!(length(cal_id) == 0)) {
+  #           # calibrate isotopologues using appropriate cal_id
+  #           uncal_12C <- ref_df$rtioMoleDryCo2$mean[i] * (1 - f) /
+  #             (1 + R_vpdb * (1 + ref_df$dlta13CCo2$mean[i] / 1000))
+  # 
+  #           uncal_13C <- ref_df$rtioMoleDryCo2$mean[i] * (1 - f) - uncal_12C
+  # 
+  #           cal_12C <- cal_df$gain12C[cal_id] * uncal_12C +
+  #             cal_df$offset12C[cal_id]
+  #           cal_13C <- cal_df$gain13C[cal_id] * uncal_13C +
+  #             cal_df$offset13C[cal_id]
+  # 
+  #           if (!is.na(cal_df$r2_12C[cal_id]) &
+  #               !is.na(cal_df$r2_13C[cal_id]) &
+  #               cal_df$r2_12C[cal_id] > r2_thres &
+  #               cal_df$r2_13C[cal_id] > r2_thres) {
+  #             ref_df$dlta13CCo2$mean_cal[i] <- round(1000 * (cal_13C /
+  #                                                    cal_12C / R_vpdb - 1), 3)
+  #             ref_df$rtioMoleDryCo2$mean_cal[i] <- (cal_13C + cal_12C) /
+  #                                                     (1 - f)
+  # 
+  #           } else {
+  # 
+  #             ref_df$dlta13CCo2$mean_cal[i] <- NA
+  #             ref_df$rtioMoleDryCo2$mean_cal[i] <- NA
+  # 
+  #           }
+  # 
+  #         } else {
+  # 
+  #           ref_df$dlta13CCo2$mean_cal[i] <- NA
+  #           ref_df$rtioMoleDryCo2$mean_cal[i] <- NA
+  # 
+  #         }
+  # 
+  #       } else {
+  # 
+  #         ref_df$dlta13CCo2$mean_cal[i] <- NA
+  #         ref_df$rtioMoleDryCo2$mean_cal[i] <- NA
+  #       }
+  #     }
+  #   }
+  # 
+  # } else {
+  # 
+  #   if (nrow(ref_df$dlta13CCo2) > 1) {
+  #     for (i in 2:nrow(ref_df$dlta13CCo2)) { # use n-1 because of bracketing
+  # 
+  #       # determine which row calibration point is in.
+  #       int <- lubridate::interval(cal_df$start, cal_df$end)
+  #       cal_id <- which(ref_df$dlta13CCo2$timeBgn[i] %within% int)
+  # 
+  #       # now, calculate calibrated value ONLY IF CERTAIN CONDITIONS ARE MET:
+  #       # 1a-d. variables needed are not missing.
+  #       # 2. at least 200 ~1Hz measmnts available (filters out valve issues)
+  #       # 3. meets tolerance between ref and measured d13C
+  #       # 4. meets tolerance between ref and measured CO2
+  #       # 5. meets tolerance of d13C variance
+  #       # these conditions are listed in this order in the logical below.
+  #       if (!is.na(ref_df$dlta13CCo2$mean[i]) &
+  #           !is.na(ref_df$dlta13CCo2Refe$mean[i]) &
+  #           !is.na(ref_df$rtioMoleDryCo2$mean[i]) &
+  #           !is.na(ref_df$rtioMoleDryCo2Refe$mean[i]) &
+  #           ref_df$dlta13CCo2$numSamp[i] >= 200 &
+  #           abs(ref_df$dlta13CCo2$mean[i] -
+  #               ref_df$dlta13CCo2Refe$mean[i]) < 5 &
+  #           abs(ref_df$rtioMoleDryCo2$mean[i] -
+  #               ref_df$rtioMoleDryCo2Refe$mean[i]) < 10 &
+  #           ref_df$dlta13CCo2$vari[i] < 5) {
+  # 
+  #         if (!length(cal_id) == 0) {
+  # 
+  #           if (!is.na(cal_df$d13C_r2[cal_id]) &
+  #               !is.na(cal_df$co2_r2[cal_id]) &
+  #               cal_df$d13C_r2[cal_id] > r2_thres &
+  #               cal_df$co2_r2[cal_id] > r2_thres) {
+  # 
+  #             ref_df$dlta13CCo2$mean_cal[i] <- cal_df$d13C_intercept[cal_id] +
+  #               cal_df$d13C_slope[cal_id] * ref_df$dlta13CCo2$mean[i]
+  # 
+  #             ref_df$rtioMoleDryCo2$mean_cal[i] <- cal_df$co2_intercept[cal_id] +
+  #               cal_df$co2_slope[cal_id] * ref_df$rtioMoleDryCo2$mean[i]
+  # 
+  #           } else {
+  # 
+  #             ref_df$dlta13CCo2$mean_cal[i] <- NA
+  #             ref_df$rtioMoleDryCo2$mean_cal[i] <- NA
+  #           }
+  # 
+  #         } else {
+  # 
+  #           ref_df$dlta13CCo2$mean_cal[i] <- NA
+  #           ref_df$rtioMoleDryCo2$mean_cal[i] <- NA
+  # 
+  #         }
+  # 
+  #       } else {
+  # 
+  #         ref_df$dlta13CCo2$mean_cal[i] <- NA
+  #         ref_df$rtioMoleDryCo2$mean_cal[i] <- NA
+  # 
+  #       }
+  #     }
+  #   }
+  # }
 
   # convert time back to NEON format.
   ref_df$dlta13CCo2$timeBgn <- convert_POSIXct_to_NEONhdf5_time(ref_df$dlta13CCo2$timeBgn)
